using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;

namespace SmartmaniaGame
{
    /// <summary>
    /// Draw actual framerate on the screen (DrawableGameComponent)
    /// </summary>
    public class DisplayFramerate : DrawableGameComponent
    {
        private ContentManager contentManager;
        private SpriteBatch spriteBatch;
        private SpriteFont spriteFont;

        private int frameRate = 0;
        private int frameCounter = 0;
        private TimeSpan elapsedTime = TimeSpan.Zero;

        public DisplayFramerate(Game game)
            : base(game)
        {
            this.contentManager = new ContentManager(game.Services);
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(Game.GraphicsDevice);
            spriteFont = contentManager.Load<SpriteFont>("Content\\FpsFont");
        }

        protected override void UnloadContent()
        {
            contentManager.Unload();
            contentManager = new ContentManager(Game.Services);
        }

        public override void Update(GameTime gameTime)
        {
            elapsedTime += gameTime.ElapsedGameTime;

            if (elapsedTime > TimeSpan.FromSeconds(1))
            {
                elapsedTime -= TimeSpan.FromSeconds(1);
                frameRate = frameCounter;
                frameCounter = 0;
            }
        }

        public override void Draw(GameTime gameTime)
        {
            frameCounter++;

            string fps = "fps: " + frameRate.ToString();

            spriteBatch.Begin();
            spriteBatch.DrawString(spriteFont, fps, new Vector2(9, 9), Color.Black);
            spriteBatch.DrawString(spriteFont, fps, new Vector2(8, 8), Color.White);
            spriteBatch.End();

            Game.GraphicsDevice.BlendState = BlendState.Opaque;
            Game.GraphicsDevice.DepthStencilState = DepthStencilState.Default;
            Game.GraphicsDevice.SamplerStates[0] = SamplerState.LinearWrap;
        }
    }

}
